function GetActiveDocument() {
  try {
    return app.documents.length ? app.activeDocument : null
  } catch (e) {
    return null
  }
}

const Environment = {
  tempFolder: function() {
    return Folder.temp.fsName
  }
}

const Helper = {
  file: function(path) {
    if (path) {
      const file = File(path)
      if (file.exists) {
        file.remove()
      }
      return file
    } else {
      return null
    }
  }
}

const ActiveDocument = {
  property: function(name) {
    const docref = GetActiveDocument()
    try {
      return docref ? docref[name] : ''
    } catch (e) {
      return undefined
    }
  },
  isSaved: function() {
    const docref = GetActiveDocument()
    try {
      return docref && docref.saved
    } catch (e) {
      return false
    }
  },
  saveAsPdf: function(path) {
    const file = Helper.file(path)
    const docref = GetActiveDocument()
    if (docref && file) {
      try {
        var pdfOptions = new PDFSaveOptions()
        pdfOptions.optimizeForWeb = true
        pdfOptions.layers = false
        docref.saveAs(file, pdfOptions, true)
        return true
      } catch (error) {}
    }
    return false
  },
  exportAsPdf: function(path) {
    const file = Helper.file(path)
    const docref = GetActiveDocument()
    if (docref && file) {
      try {
        docref.exportFile(ExportFormat.pdfType, file)
        return true
      } catch (error) {}
    }
    return false
  },
  saveAsPng: function(path) {
    const file = Helper.file(path)
    const docref = GetActiveDocument()
    if (docref && file) {
      try {
        var options = new PNGSaveOptions()
        options.interlaced = false
        options.compression = 9
        docref.saveAs(file, options, true)
        return true
      } catch (error) {}
    }
    return false
  },
  exportAsPng24: function(path) {
    const file = Helper.file(path)
    const docref = GetActiveDocument()
    if (docref && file) {
      try {
        var options = new ExportOptionsPNG24()
        options.matte = false
        docref.exportFile(file, ExportType.PNG24, options)
        return true
      } catch (error) {}
    }
    return false
  },
  exportAsPng: function(path) {
    const file = Helper.file(path)
    const docref = GetActiveDocument()
    if (docref && file) {
      try {
        docref.exportFile(ExportFormat.PNG_FORMAT, file)
        return true
      } catch (error) {}
    }
    return false
  },
  saveAsJpg: function(path) {
    const file = Helper.file(path)
    const docref = GetActiveDocument()
    if (docref && file) {
      try {
        var options = new JPEGSaveOptions()
        options.embedColorProfile = false
        options.quality = 6
        options.matte = MatteType.NONE
        docref.saveAs(file, options, true)
        return true
      } catch (error) {}
    }
    return false
  },
  exportAsJpeg: function(path) {
    const file = Helper.file(path)
    const docref = GetActiveDocument()
    if (docref && file) {
      try {
        var options = new ExportOptionsJPEG()
        options.blurAmount = 0
        options.matte = false
        options.qualitySetting = 60
        docref.exportFile(file, ExportType.JPEG, options)
        return true
      } catch (error) {}
    }
    return false
  },
  exportAsJpg: function(path) {
    const file = Helper.file(path)
    const docref = GetActiveDocument()
    if (docref && file) {
      try {
        docref.exportFile(ExportFormat.JPG, file)
        return true
      } catch (error) {}
    }
    return false
  }
}
